## ---------------------------------------------------------------------
##
## Copyright (C) 2012 - 2017 by the deal.II authors
##
## This file is part of the deal.II library.
##
## The deal.II library is free software; you can use it, redistribute
## it, and/or modify it under the terms of the GNU Lesser General
## Public License as published by the Free Software Foundation; either
## version 2.1 of the License, or (at your option) any later version.
## The full text of the license can be found in the file LICENSE at
## the top level of the deal.II distribution.
##
## ---------------------------------------------------------------------


########################################################################
##                                                                    ##
##               The deal.II project configuration file               ##
##                                                                    ##
########################################################################


#
# General information
#

SET(DEAL_II_PACKAGE_NAME "deal.II")
SET(DEAL_II_PACKAGE_VERSION "9.0.1")
SET(DEAL_II_PACKAGE_VENDOR "The deal.II Authors <http://www.dealii.org/>")
SET(DEAL_II_PACKAGE_DESCRIPTION "Library for solving partial differential equations with the finite element method")

SET(DEAL_II_VERSION_MAJOR "9")
SET(DEAL_II_VERSION_MINOR "0")
SET(DEAL_II_VERSION_SUBMINOR "1")
SET(DEAL_II_VERSION "9.0.1")

SET(DEAL_II_GIT_BRANCH "")
SET(DEAL_II_GIT_REVISION "")
SET(DEAL_II_GIT_SHORTREV "")
SET(DEAL_II_GIT_TAG "")

SET(DEAL_II_PROJECT_CONFIG_NAME "deal.II")

SET(DEAL_II_BUILD_TYPE "DebugRelease")
SET(DEAL_II_BUILD_TYPES "DEBUG;RELEASE")


#
# Information about the project location
#

SET(DEAL_II_DOCHTML_RELDIR "share/doc/libdeal.ii-doc/html")
SET(DEAL_II_DOCREADME_RELDIR "share/doc/libdeal.ii-doc")
SET(DEAL_II_EXAMPLES_RELDIR "share/doc/libdeal.ii-doc/examples")
SET(DEAL_II_EXECUTABLE_RELDIR "bin")
SET(DEAL_II_INCLUDE_RELDIR "include")
SET(DEAL_II_LIBRARY_RELDIR "lib/mips64el-linux-gnuabi64")
SET(DEAL_II_PROJECT_CONFIG_RELDIR "share/cmake/deal.II")
SET(DEAL_II_SHARE_RELDIR "share/deal.ii/")

#
# Determine DEAL_II_PATH from CMAKE_CURRENT_LIST_DIR:
#

SET(DEAL_II_PATH "${CMAKE_CURRENT_LIST_DIR}")
SET(_path "${DEAL_II_PROJECT_CONFIG_RELDIR}")
WHILE(NOT "${_path}" STREQUAL "")
  GET_FILENAME_COMPONENT(DEAL_II_PATH "${DEAL_II_PATH}" PATH)
  GET_FILENAME_COMPONENT(_path "${_path}" PATH)
ENDWHILE()

#
# Print a message after inclusion of this file:
#

SET(DEAL_II_PROJECT_CONFIG_INCLUDED TRUE)

SET(DEAL_II_BUILD_DIR FALSE)

IF(NOT ${DEAL_II_PACKAGE_NAME}_FIND_QUIETLY)
  IF(DEAL_II_BUILD_DIR)
    MESSAGE(STATUS
      "Using the ${DEAL_II_PACKAGE_NAME}-${DEAL_II_PACKAGE_VERSION} build directory found at ${DEAL_II_PATH}"
      )
  ELSE()
    MESSAGE(STATUS
      "Using the ${DEAL_II_PACKAGE_NAME}-${DEAL_II_PACKAGE_VERSION} installation found at ${DEAL_II_PATH}"
      )
  ENDIF()
ENDIF()


#
# Include all convenience macros:
#

FILE(GLOB _macro_files
  "${DEAL_II_PATH}/${DEAL_II_SHARE_RELDIR}/macros/*.cmake"
  )
FOREACH(file ${_macro_files})
  IF(NOT ${DEAL_II_PACKAGE_NAME}_FIND_QUIETLY)
    MESSAGE(STATUS "Include macro ${file}")
  ENDIF()
  INCLUDE(${file})
ENDFOREACH()


#
# Compiler and linker configuration
#

SET(DEAL_II_CXX_COMPILER "/usr/bin/c++")
SET(DEAL_II_C_COMPILER "/usr/bin/cc")

# used for all targets:
SET(DEAL_II_CXX_FLAGS "-pedantic -fPIC -Wall -Wextra -Wpointer-arith -Wwrite-strings -Wsynth -Wsign-compare -Wswitch -Woverloaded-virtual -Wno-placement-new  -Wno-literal-suffix -fopenmp-simd -std=c++17 -g -O2 -fdebug-prefix-map=/build/deal.ii-9.0.1=. -fstack-protector-strong -Wformat -Werror=format-security -Wdate-time -D_FORTIFY_SOURCE=2 -Wno-nonnull-compare -Wno-address -Wno-unused-local-typedefs")

# _additionally_ used for debug targets:
SET(DEAL_II_CXX_FLAGS_DEBUG "-Og -ggdb -Wa,--compress-debug-sections")

# _additionally_ used for release targets:
SET(DEAL_II_CXX_FLAGS_RELEASE "-O2 -funroll-loops -funroll-all-loops -fstrict-aliasing -Wno-unused-local-typedefs")

# used for all targets:
SET(DEAL_II_LINKER_FLAGS "-rdynamic -Wl,-z,relro -pthread -pthread")

# _additionally_ used for debug targets:
SET(DEAL_II_LINKER_FLAGS_DEBUG "-ggdb")

# _additionally_ used for release targets:
SET(DEAL_II_LINKER_FLAGS_RELEASE "")

# used for all targets:
SET(DEAL_II_USER_DEFINITIONS "BOOST_NO_AUTO_PTR")

# _additionally_ used for debug targets:
SET(DEAL_II_USER_DEFINITIONS_DEBUG "DEBUG")

# _additionally_ used for release targets:
SET(DEAL_II_USER_DEFINITIONS_RELEASE "")

#
# MPI runtime:
#

SET(DEAL_II_MPIEXEC "/usr/bin/mpiexec")
SET(DEAL_II_MPIEXEC_NUMPROC_FLAG "-n")
SET(DEAL_II_MPIEXEC_PREFLAGS "")
SET(DEAL_II_MPIEXEC_POSTFLAGS "")

#
# Build a static executable:
#

SET(DEAL_II_STATIC_EXECUTABLE "OFF")


#
# Information about include directories and libraries
#

# Full list of include directories:
SET(DEAL_II_INCLUDE_DIRS "${DEAL_II_PATH}/${DEAL_II_INCLUDE_RELDIR};${DEAL_II_PATH}/${DEAL_II_INCLUDE_RELDIR}/deal.II/bundled;/usr/lib/mips64el-linux-gnuabi64/openmpi/include/openmpi;/usr/lib/mips64el-linux-gnuabi64/openmpi/include;/usr/include;/usr/include/trilinos;/usr/include/hdf5/openmpi;/usr/include/scotch;/usr/include/suitesparse;/usr/include/petsc;/usr/lib/mips64el-linux-gnuabi64/hdf5/openmpi/include;/usr/include/oce;/usr/include/slepc")

# Full list of libraries for the debug target:
SET(DEAL_II_LIBRARIES_DEBUG "${DEAL_II_PATH}/lib/mips64el-linux-gnuabi64/libdeal.ii.g.so;/usr/lib/mips64el-linux-gnuabi64/libboost_iostreams.so;/usr/lib/mips64el-linux-gnuabi64/libboost_serialization.so;/usr/lib/mips64el-linux-gnuabi64/libboost_system.so;/usr/lib/mips64el-linux-gnuabi64/libboost_thread.so;-pthread;/usr/lib/mips64el-linux-gnuabi64/libboost_regex.so;/usr/lib/mips64el-linux-gnuabi64/libboost_chrono.so;/usr/lib/mips64el-linux-gnuabi64/libboost_date_time.so;/usr/lib/mips64el-linux-gnuabi64/libboost_atomic.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_pike-blackbox.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_trilinoscouplings.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_piro.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_rol.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stokhos_muelu.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stokhos_ifpack2.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stokhos_amesos2.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stokhos_tpetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stokhos_sacado.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stokhos.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_rythmos.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_muelu-adapters.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_muelu-interface.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_muelu.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_moertel.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_locathyra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_locaepetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_localapack.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_loca.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_noxepetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_noxlapack.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_nox.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_phalanx.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_intrepid.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_teko.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stratimikos.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stratimikosbelos.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stratimikosaztecoo.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stratimikosamesos.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stratimikosml.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stratimikosifpack.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_ifpack2-adapters.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_ifpack2.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_anasazitpetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_ModeLaplace.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_anasaziepetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_anasazi.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_komplex.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_amesos2.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_shylu.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_belostpetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_belosepetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_belos.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_ml.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_ifpack.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_zoltan2.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_pamgen_extras.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_pamgen.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_amesos.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_galeri-xpetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_galeri-epetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_aztecoo.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_dpliris.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_isorropia.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_optipack.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_xpetra-sup.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_xpetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_thyratpetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_thyraepetraext.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_thyraepetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_thyracore.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_epetraext.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_trilinosss.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_tpetraext.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_tpetrainout.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_tpetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_kokkostsqr.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_tpetraclassiclinalg.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_tpetraclassicnodeapi.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_tpetraclassic.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_triutils.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_globipack.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_shards.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_zoltan.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_epetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_sacado.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_rtop.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_kokkoskernels.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_teuchoskokkoscomm.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_teuchoskokkoscompat.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_teuchosremainder.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_teuchosnumerics.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_teuchoscomm.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_teuchosparameterlist.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_teuchoscore.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_kokkosalgorithms.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_kokkoscontainers.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_kokkoscore.so;/usr/lib/mips64el-linux-gnuabi64/libsmumps.so;/usr/lib/mips64el-linux-gnuabi64/libdmumps.so;/usr/lib/mips64el-linux-gnuabi64/libcmumps.so;/usr/lib/mips64el-linux-gnuabi64/libzmumps.so;/usr/lib/mips64el-linux-gnuabi64/libpord.so;/usr/lib/mips64el-linux-gnuabi64/libmumps_common.so;/usr/lib/mips64el-linux-gnuabi64/hdf5/openmpi/libhdf5.so;/usr/lib/mips64el-linux-gnuabi64/libtbb.so;/usr/lib/mips64el-linux-gnuabi64/libz.so;/usr/lib/mips64el-linux-gnuabi64/libptscotch.so;/usr/lib/mips64el-linux-gnuabi64/libptscotcherr.so;/usr/lib/mips64el-linux-gnuabi64/libscotch.so;/usr/lib/mips64el-linux-gnuabi64/libscotcherr.so;dl;/usr/lib/mips64el-linux-gnuabi64/openmpi/lib/libmpi_cxx.so;/usr/lib/mips64el-linux-gnuabi64/libumfpack.so;/usr/lib/mips64el-linux-gnuabi64/libcholmod.so;/usr/lib/mips64el-linux-gnuabi64/libccolamd.so;/usr/lib/mips64el-linux-gnuabi64/libcolamd.so;/usr/lib/mips64el-linux-gnuabi64/libcamd.so;/usr/lib/mips64el-linux-gnuabi64/libsuitesparseconfig.so;/usr/lib/mips64el-linux-gnuabi64/libamd.so;rt;/usr/lib/mips64el-linux-gnuabi64/libparpack.so;/usr/lib/mips64el-linux-gnuabi64/libarpack.so;/usr/lib/mips64el-linux-gnuabi64/libassimp.so;/usr/lib/mips64el-linux-gnuabi64/libgsl.so;/usr/lib/mips64el-linux-gnuabi64/libgslcblas.so;/usr/lib/mips64el-linux-gnuabi64/hdf5/openmpi/lib/lib/libhdf5_hl.so;/usr/lib/mips64el-linux-gnuabi64/hdf5/openmpi/lib/lib/libhdf5.so;/usr/lib/mips64el-linux-gnuabi64/libmuparser.so;/usr/lib/mips64el-linux-gnuabi64/libnetcdf_c++.so;/usr/lib/mips64el-linux-gnuabi64/libnetcdf.so;/usr/lib/mips64el-linux-gnuabi64/libTKBO.so;/usr/lib/mips64el-linux-gnuabi64/libTKBool.so;/usr/lib/mips64el-linux-gnuabi64/libTKBRep.so;/usr/lib/mips64el-linux-gnuabi64/libTKernel.so;/usr/lib/mips64el-linux-gnuabi64/libTKFeat.so;/usr/lib/mips64el-linux-gnuabi64/libTKFillet.so;/usr/lib/mips64el-linux-gnuabi64/libTKG2d.so;/usr/lib/mips64el-linux-gnuabi64/libTKG3d.so;/usr/lib/mips64el-linux-gnuabi64/libTKGeomAlgo.so;/usr/lib/mips64el-linux-gnuabi64/libTKGeomBase.so;/usr/lib/mips64el-linux-gnuabi64/libTKHLR.so;/usr/lib/mips64el-linux-gnuabi64/libTKIGES.so;/usr/lib/mips64el-linux-gnuabi64/libTKMath.so;/usr/lib/mips64el-linux-gnuabi64/libTKMesh.so;/usr/lib/mips64el-linux-gnuabi64/libTKOffset.so;/usr/lib/mips64el-linux-gnuabi64/libTKPrim.so;/usr/lib/mips64el-linux-gnuabi64/libTKShHealing.so;/usr/lib/mips64el-linux-gnuabi64/libTKSTEP.so;/usr/lib/mips64el-linux-gnuabi64/libTKSTEPAttr.so;/usr/lib/mips64el-linux-gnuabi64/libTKSTEPBase.so;/usr/lib/mips64el-linux-gnuabi64/libTKSTEP209.so;/usr/lib/mips64el-linux-gnuabi64/libTKSTL.so;/usr/lib/mips64el-linux-gnuabi64/libTKTopAlgo.so;/usr/lib/mips64el-linux-gnuabi64/libTKXSBase.so;/usr/lib/mips64el-linux-gnuabi64/libp4est.so;/usr/lib/mips64el-linux-gnuabi64/libsc.so;/usr/lib/mips64el-linux-gnuabi64/libscalapack-openmpi.so;/usr/lib/mips64el-linux-gnuabi64/liblapack.so;/usr/lib/mips64el-linux-gnuabi64/libblas.so;gfortran;m;c;gcc_s;gcc;/usr/lib/mips64el-linux-gnuabi64/openmpi/lib/libmpi_usempif08.so;/usr/lib/mips64el-linux-gnuabi64/openmpi/lib/libmpi_usempi_ignore_tkr.so;/usr/lib/mips64el-linux-gnuabi64/openmpi/lib/libmpi_mpifh.so;/usr/lib/mips64el-linux-gnuabi64/openmpi/lib/libmpi.so;/usr/lib/mips64el-linux-gnuabi64/libslepc.so;/usr/lib/mips64el-linux-gnuabi64/libpetsc.so;/usr/lib/mips64el-linux-gnuabi64/libsundials_idas.so;/usr/lib/mips64el-linux-gnuabi64/libsundials_arkode.so;/usr/lib/mips64el-linux-gnuabi64/libsundials_kinsol.so;/usr/lib/mips64el-linux-gnuabi64/libsundials_nvecserial.so;/usr/lib/mips64el-linux-gnuabi64/libsundials_nvecparallel.so")

# Full list of libraries for the release target:
SET(DEAL_II_LIBRARIES_RELEASE "${DEAL_II_PATH}/lib/mips64el-linux-gnuabi64/libdeal.ii.so;/usr/lib/mips64el-linux-gnuabi64/libboost_iostreams.so;/usr/lib/mips64el-linux-gnuabi64/libboost_serialization.so;/usr/lib/mips64el-linux-gnuabi64/libboost_system.so;/usr/lib/mips64el-linux-gnuabi64/libboost_thread.so;-pthread;/usr/lib/mips64el-linux-gnuabi64/libboost_regex.so;/usr/lib/mips64el-linux-gnuabi64/libboost_chrono.so;/usr/lib/mips64el-linux-gnuabi64/libboost_date_time.so;/usr/lib/mips64el-linux-gnuabi64/libboost_atomic.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_pike-blackbox.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_trilinoscouplings.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_piro.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_rol.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stokhos_muelu.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stokhos_ifpack2.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stokhos_amesos2.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stokhos_tpetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stokhos_sacado.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stokhos.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_rythmos.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_muelu-adapters.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_muelu-interface.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_muelu.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_moertel.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_locathyra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_locaepetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_localapack.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_loca.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_noxepetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_noxlapack.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_nox.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_phalanx.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_intrepid.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_teko.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stratimikos.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stratimikosbelos.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stratimikosaztecoo.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stratimikosamesos.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stratimikosml.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_stratimikosifpack.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_ifpack2-adapters.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_ifpack2.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_anasazitpetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_ModeLaplace.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_anasaziepetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_anasazi.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_komplex.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_amesos2.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_shylu.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_belostpetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_belosepetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_belos.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_ml.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_ifpack.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_zoltan2.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_pamgen_extras.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_pamgen.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_amesos.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_galeri-xpetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_galeri-epetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_aztecoo.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_dpliris.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_isorropia.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_optipack.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_xpetra-sup.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_xpetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_thyratpetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_thyraepetraext.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_thyraepetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_thyracore.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_epetraext.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_trilinosss.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_tpetraext.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_tpetrainout.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_tpetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_kokkostsqr.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_tpetraclassiclinalg.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_tpetraclassicnodeapi.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_tpetraclassic.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_triutils.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_globipack.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_shards.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_zoltan.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_epetra.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_sacado.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_rtop.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_kokkoskernels.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_teuchoskokkoscomm.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_teuchoskokkoscompat.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_teuchosremainder.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_teuchosnumerics.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_teuchoscomm.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_teuchosparameterlist.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_teuchoscore.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_kokkosalgorithms.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_kokkoscontainers.so;/usr/lib/mips64el-linux-gnuabi64/libtrilinos_kokkoscore.so;/usr/lib/mips64el-linux-gnuabi64/libsmumps.so;/usr/lib/mips64el-linux-gnuabi64/libdmumps.so;/usr/lib/mips64el-linux-gnuabi64/libcmumps.so;/usr/lib/mips64el-linux-gnuabi64/libzmumps.so;/usr/lib/mips64el-linux-gnuabi64/libpord.so;/usr/lib/mips64el-linux-gnuabi64/libmumps_common.so;/usr/lib/mips64el-linux-gnuabi64/hdf5/openmpi/libhdf5.so;/usr/lib/mips64el-linux-gnuabi64/libtbb.so;/usr/lib/mips64el-linux-gnuabi64/libz.so;/usr/lib/mips64el-linux-gnuabi64/libptscotch.so;/usr/lib/mips64el-linux-gnuabi64/libptscotcherr.so;/usr/lib/mips64el-linux-gnuabi64/libscotch.so;/usr/lib/mips64el-linux-gnuabi64/libscotcherr.so;dl;/usr/lib/mips64el-linux-gnuabi64/openmpi/lib/libmpi_cxx.so;/usr/lib/mips64el-linux-gnuabi64/libumfpack.so;/usr/lib/mips64el-linux-gnuabi64/libcholmod.so;/usr/lib/mips64el-linux-gnuabi64/libccolamd.so;/usr/lib/mips64el-linux-gnuabi64/libcolamd.so;/usr/lib/mips64el-linux-gnuabi64/libcamd.so;/usr/lib/mips64el-linux-gnuabi64/libsuitesparseconfig.so;/usr/lib/mips64el-linux-gnuabi64/libamd.so;rt;/usr/lib/mips64el-linux-gnuabi64/libparpack.so;/usr/lib/mips64el-linux-gnuabi64/libarpack.so;/usr/lib/mips64el-linux-gnuabi64/libassimp.so;/usr/lib/mips64el-linux-gnuabi64/libgsl.so;/usr/lib/mips64el-linux-gnuabi64/libgslcblas.so;/usr/lib/mips64el-linux-gnuabi64/hdf5/openmpi/lib/lib/libhdf5_hl.so;/usr/lib/mips64el-linux-gnuabi64/hdf5/openmpi/lib/lib/libhdf5.so;/usr/lib/mips64el-linux-gnuabi64/libmuparser.so;/usr/lib/mips64el-linux-gnuabi64/libnetcdf_c++.so;/usr/lib/mips64el-linux-gnuabi64/libnetcdf.so;/usr/lib/mips64el-linux-gnuabi64/libTKBO.so;/usr/lib/mips64el-linux-gnuabi64/libTKBool.so;/usr/lib/mips64el-linux-gnuabi64/libTKBRep.so;/usr/lib/mips64el-linux-gnuabi64/libTKernel.so;/usr/lib/mips64el-linux-gnuabi64/libTKFeat.so;/usr/lib/mips64el-linux-gnuabi64/libTKFillet.so;/usr/lib/mips64el-linux-gnuabi64/libTKG2d.so;/usr/lib/mips64el-linux-gnuabi64/libTKG3d.so;/usr/lib/mips64el-linux-gnuabi64/libTKGeomAlgo.so;/usr/lib/mips64el-linux-gnuabi64/libTKGeomBase.so;/usr/lib/mips64el-linux-gnuabi64/libTKHLR.so;/usr/lib/mips64el-linux-gnuabi64/libTKIGES.so;/usr/lib/mips64el-linux-gnuabi64/libTKMath.so;/usr/lib/mips64el-linux-gnuabi64/libTKMesh.so;/usr/lib/mips64el-linux-gnuabi64/libTKOffset.so;/usr/lib/mips64el-linux-gnuabi64/libTKPrim.so;/usr/lib/mips64el-linux-gnuabi64/libTKShHealing.so;/usr/lib/mips64el-linux-gnuabi64/libTKSTEP.so;/usr/lib/mips64el-linux-gnuabi64/libTKSTEPAttr.so;/usr/lib/mips64el-linux-gnuabi64/libTKSTEPBase.so;/usr/lib/mips64el-linux-gnuabi64/libTKSTEP209.so;/usr/lib/mips64el-linux-gnuabi64/libTKSTL.so;/usr/lib/mips64el-linux-gnuabi64/libTKTopAlgo.so;/usr/lib/mips64el-linux-gnuabi64/libTKXSBase.so;/usr/lib/mips64el-linux-gnuabi64/libp4est.so;/usr/lib/mips64el-linux-gnuabi64/libsc.so;/usr/lib/mips64el-linux-gnuabi64/libscalapack-openmpi.so;/usr/lib/mips64el-linux-gnuabi64/liblapack.so;/usr/lib/mips64el-linux-gnuabi64/libblas.so;gfortran;m;c;gcc_s;gcc;/usr/lib/mips64el-linux-gnuabi64/openmpi/lib/libmpi_usempif08.so;/usr/lib/mips64el-linux-gnuabi64/openmpi/lib/libmpi_usempi_ignore_tkr.so;/usr/lib/mips64el-linux-gnuabi64/openmpi/lib/libmpi_mpifh.so;/usr/lib/mips64el-linux-gnuabi64/openmpi/lib/libmpi.so;/usr/lib/mips64el-linux-gnuabi64/libslepc.so;/usr/lib/mips64el-linux-gnuabi64/libpetsc.so;/usr/lib/mips64el-linux-gnuabi64/libsundials_idas.so;/usr/lib/mips64el-linux-gnuabi64/libsundials_arkode.so;/usr/lib/mips64el-linux-gnuabi64/libsundials_kinsol.so;/usr/lib/mips64el-linux-gnuabi64/libsundials_nvecserial.so;/usr/lib/mips64el-linux-gnuabi64/libsundials_nvecparallel.so")

# Full list of libraries with "debug" and "optimized" keywords for easy use with TARGET_LINK_LIBRARIES:
SET(DEAL_II_LIBRARIES "debug;${DEAL_II_LIBRARIES_DEBUG};optimized;${DEAL_II_LIBRARIES_RELEASE}")


#
# Information about CUDA configuration
#

SET(DEAL_II_CUDA_TOOLKIT_ROOT_DIR "")
SET(DEAL_II_CUDA_COMPILER "")

# used for all cuda targets:
SET(DEAL_II_CUDA_FLAGS "")

# _additionally_ used for debug targets:
SET(DEAL_II_CUDA_FLAGS_DEBUG "")

# _additionally_ used for release targets:
SET(DEAL_II_CUDA_FLAGS_RELEASE "")


#
# Information about library targets and feature configuration
#

# The library targets file:
SET(DEAL_II_TARGET_CONFIG "${DEAL_II_PATH}/${DEAL_II_PROJECT_CONFIG_RELDIR}/${DEAL_II_PROJECT_CONFIG_NAME}Targets.cmake")

# The Debug target:
SET(DEAL_II_TARGET_DEBUG "deal.ii.g")

# The Release target:
SET(DEAL_II_TARGET_RELEASE "deal.ii")

# Full list of targets with "debug" and "optimized" keywords for easy use with TARGET_LINK_LIBRARIES:
SET(DEAL_II_TARGET "debug;${DEAL_II_TARGET_DEBUG};optimized;${DEAL_II_TARGET_RELEASE}")

# The feature configuration file:
SET(DEAL_II_FEATURE_CONFIG "${DEAL_II_PATH}/${DEAL_II_PROJECT_CONFIG_RELDIR}/${DEAL_II_PROJECT_CONFIG_NAME}FeatureConfig.cmake")


#
# Feature configuration:
#

SET(DEAL_II_WITH_CXX11 ON)
SET(DEAL_II_WITH_64BIT_INDICES OFF)
SET(DEAL_II_WITH_ADOLC OFF)
SET(DEAL_II_WITH_ARPACK ON)
SET(DEAL_II_ARPACK_WITH_PARPACK TRUE)
SET(DEAL_II_WITH_ASSIMP ON)
SET(DEAL_II_WITH_BOOST ON)
SET(DEAL_II_BOOST_VERSION "1.67.0")
SET(DEAL_II_WITH_CUDA OFF)
SET(DEAL_II_WITH_CXX14 ON)
SET(DEAL_II_WITH_CXX17 ON)
SET(DEAL_II_WITH_GMSH ON)
SET(DEAL_II_WITH_GSL ON)
SET(DEAL_II_GSL_VERSION "2.5")
SET(DEAL_II_WITH_HDF5 ON)
SET(DEAL_II_WITH_LAPACK ON)
SET(DEAL_II_WITH_METIS OFF)
SET(DEAL_II_WITH_MPI ON)
SET(DEAL_II_MPI_VERSION "3.1")
SET(DEAL_II_WITH_MUPARSER ON)
SET(DEAL_II_MUPARSER_VERSION "2.2.6")
SET(DEAL_II_WITH_NANOFLANN OFF)
SET(DEAL_II_WITH_NETCDF ON)
SET(DEAL_II_WITH_OPENCASCADE ON)
SET(DEAL_II_OPENCASCADE_VERSION "6.9.1")
SET(DEAL_II_WITH_P4EST ON)
SET(DEAL_II_P4EST_VERSION "1.1")
SET(DEAL_II_WITH_PETSC ON)
SET(DEAL_II_PETSC_VERSION "3.10.3.0")
SET(DEAL_II_PETSC_WITH_COMPLEX FALSE)
SET(DEAL_II_PETSC_WITH_HYPRE TRUE)
SET(DEAL_II_PETSC_WITH_MUMPS TRUE)
SET(DEAL_II_WITH_SCALAPACK ON)
SET(DEAL_II_WITH_SLEPC ON)
SET(DEAL_II_SLEPC_VERSION "3.10.1.0")
SET(DEAL_II_WITH_SUNDIALS ON)
SET(DEAL_II_SUNDIALS_WITH_IDAS TRUE)
SET(DEAL_II_WITH_THREADS ON)
SET(DEAL_II_WITH_TRILINOS ON)
SET(DEAL_II_TRILINOS_VERSION "12.12.1")
SET(DEAL_II_TRILINOS_WITH_ROL ON)
SET(DEAL_II_TRILINOS_WITH_ZOLTAN ON)
SET(DEAL_II_WITH_UMFPACK ON)
SET(DEAL_II_UMFPACK_VERSION "5.7.8")
SET(DEAL_II_WITH_ZLIB ON)
SET(DEAL_II_ZLIB_VERSION "1.2.11")
